Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(269)

Unified Diff: src/gpu/GrTest.h

Issue 1211123004: Revert of Return GrGLContext from GrTestTarget (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrGpu.h ('k') | src/gpu/GrTest.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrTest.h
diff --git a/src/gpu/GrTest.h b/src/gpu/GrTest.h
index 7e2ffed540bb7bb1d19998f74a9c27e1f4ede885..f1f3cf6c14dcf2cb554257eed84607605454130e 100644
--- a/src/gpu/GrTest.h
+++ b/src/gpu/GrTest.h
@@ -11,26 +11,26 @@
#include "GrContext.h"
#include "GrDrawTarget.h"
-#include "gl/GrGLContext.h"
+#include "gl/GrGLInterface.h"
/** Allows a test to temporarily draw to a GrDrawTarget owned by a GrContext. Tests that use this
should be careful not to mix using the GrDrawTarget directly and drawing via SkCanvas or
GrContext. In the future this object may provide some guards to prevent this. */
class GrTestTarget {
public:
- GrTestTarget() : fGLContext(NULL) {};
+ GrTestTarget() {};
- void init(GrContext*, GrDrawTarget*, const GrGLContext*);
+ void init(GrContext*, GrDrawTarget*, const GrGLInterface*);
GrDrawTarget* target() { return fDrawTarget.get(); }
- /** Returns a GrGLContext if the GrContext is backed by OpenGL. */
- const GrGLContext* glContext() { return fGLContext; }
+ /** Returns a GrGLInterface if the GrContext is backed by OpenGL. */
+ const GrGLInterface* glInterface() { return fGLInterface.get(); }
private:
SkAutoTUnref<GrDrawTarget> fDrawTarget;
SkAutoTUnref<GrContext> fContext;
- SkAutoTUnref<const GrGLContext> fGLContext;
+ SkAutoTUnref<const GrGLInterface> fGLInterface;
};
#endif
« no previous file with comments | « src/gpu/GrGpu.h ('k') | src/gpu/GrTest.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698